aboutsummaryrefslogtreecommitdiff
path: root/bdep/new-types.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'bdep/new-types.hxx')
-rw-r--r--bdep/new-types.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/bdep/new-types.hxx b/bdep/new-types.hxx
index 0b2a4c6..b7161cd 100644
--- a/bdep/new-types.hxx
+++ b/bdep/new-types.hxx
@@ -35,9 +35,9 @@ namespace bdep
BARE bare_opt;
};
// Default is bare with no options.
//
- cmd_new_type_template (): type (bare) {bare_opt = BARE ();}
+ cmd_new_type_template (): type (exe) {bare_opt = BARE ();}
friend ostream&
operator<< (ostream& os, const cmd_new_type_template& t)
@@ -35,9 +35,9 @@ namespace bdep
BARE bare_opt;
};
- // Default is bare with no options.
+ // Default is exe with no options.
//